<?php
/**
 * Theme functions and definitions.
 *
 * For additional information on potential customization options.
 *
 * @package HelloElementorChild
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

define( 'HELLO_ELEMENTOR_CHILD_VERSION', '1.0.0' );

/**
 * Load child theme scripts & styles.
 *
 * @return void
 */
add_action("wp_enqueue_scripts", "wp_child_theme");
function wp_child_theme() 
{
	if((esc_attr(get_option("wp_child_theme_setting")) != "Yes")) 
	{
		wp_enqueue_style("parent-stylesheet", get_template_directory_uri()."/style.css");
	}

	wp_enqueue_style("child-stylesheet", get_stylesheet_uri());
	wp_enqueue_style('slick-carousel-style', 'https://cdn.jsdelivr.net/npm/slick-carousel@1.8.1/slick/slick.css');
	wp_enqueue_script("child-scripts", get_stylesheet_directory_uri() . "/js/view.js", array("jquery"), "6.1.1", true);
	wp_enqueue_script('slick-carousel', 'https://cdn.jsdelivr.net/npm/slick-carousel@1.8.1/slick/slick.min.js', array('jquery'), '1.8.1', true);
}

function wp_child_theme_register_settings() 
{ 
	register_setting("wp_child_theme_options_page", "wp_child_theme_setting", "wct_callback");
}
add_action("admin_init", "wp_child_theme_register_settings");

function wp_child_theme_register_options_page() 
{
	add_options_page("Child Theme Settings", "Child Theme", "manage_options", "wp_child_theme", "wp_child_theme_register_options_page_form");
}
add_action("admin_menu", "wp_child_theme_register_options_page");

function wp_child_theme_register_options_page_form()
{ 
?>
<div id="wp_child_theme">
	<h1>Child Theme Options</h1>
	<h2>Include or Exclude Parent Theme Stylesheet</h2>
	<form method="post" action="options.php">
		<?php settings_fields("wp_child_theme_options_page"); ?>
		<p><label><input size="3" type="checkbox" name="wp_child_theme_setting" id="wp_child_theme_setting" <?php if((esc_attr(get_option("wp_child_theme_setting")) == "Yes")) { echo " checked "; } ?> value="Yes"> Tick To Disable The Parent Stylesheet (style.css) In Your Site HTML</label></p>
		<?php submit_button(); ?>
	</form>
	<p>Only Tick This Box If When You Inspect Your Source Code It Contains Your Parent Stylesheet style.css Two Times.</p>
</div>
<?php
}

//

function change_admin_footer()
{ 
echo 'Copyright &copy; <script type="text/javascript">document.write(new Date().getFullYear())</script>. All Rights Reserved. Design & Developed By <a href="https://logomentary.com/" target="_blank">Logomentary Team</a>';
}
add_action( 'admin_footer_text', 'change_admin_footer' );


function remove_admin_bar_links()
{
	global $wp_admin_bar;
	$wp_admin_bar->remove_menu('wp-logo');
}
add_action( 'wp_before_admin_bar_render', 'remove_admin_bar_links' );

function add_admin_bar_links()
{
	global $wp_admin_bar;
	$wp_admin_bar->add_menu([
		'id' => 'logomentary',
		'title' => 'Logomentary',
		'href' => 'logomentary.com',
		'meta' =>  ['target' => '_blank'] 
	]);
}
add_action( 'admin_bar_menu', 'add_admin_bar_links' );
//

// Register the HTML Block post type
function register_html_block_post_type() {
    $labels = array(
        'name'               => __( 'HTML Blocks', 'text-domain' ),
        'singular_name'      => __( 'HTML Block', 'text-domain' ),
        'menu_name'          => __( 'HTML Blocks', 'text-domain' ),
        'add_new'            => __( 'Add New', 'text-domain' ),
        'add_new_item'       => __( 'Add New HTML Block', 'text-domain' ),
        'edit_item'          => __( 'Edit HTML Block', 'text-domain' ),
        'new_item'           => __( 'New HTML Block', 'text-domain' ),
        'view_item'          => __( 'View HTML Block', 'text-domain' ),
        'search_items'       => __( 'Search HTML Blocks', 'text-domain' ),
        'not_found'          => __( 'No HTML Blocks found', 'text-domain' ),
        'not_found_in_trash' => __( 'No HTML Blocks found in Trash', 'text-domain' ),
        'all_items'          => __( 'All HTML Blocks', 'text-domain' ),
    );

    $args = array(
        'labels'              => $labels,
        'public'              => true,
        'publicly_queryable'  => true,
        'show_ui'             => true,
        'show_in_menu'        => true,
        'query_var'           => true,
        'rewrite'             => array( 'slug' => 'html-block' ),
        'capability_type'     => 'post',
        'has_archive'         => true,
        'hierarchical'        => false,
        'menu_position'       => null,
	'menu_icon'           => 'dashicons-layout',
        'show_in_rest'        => true, // Enable Gutenberg editor support
        'supports'            => array( 'title', 'editor', 'author' ),
        'exclude_from_search' => true, // Exclude from default search
    );

    register_post_type( 'html_block', $args );
}
add_action( 'init', 'register_html_block_post_type' );

// Enable shortcodes for HTML Blocks
add_filter( 'widget_text_content', 'do_shortcode' );

// Add column for auto-generated shortcode in post type dashboard
function add_shortcode_column( $columns ) {
    $columns['shortcode'] = __( 'Shortcode', 'text-domain' );
    return $columns;
}
add_filter( 'manage_html_block_posts_columns', 'add_shortcode_column' );

// Populate shortcode column with auto-generated shortcode
function populate_shortcode_column( $column, $post_id ) {
    if ( $column === 'shortcode' ) {
        $shortcode = '[html_block id="' . $post_id . '"]';
        echo esc_html( $shortcode );
    }
}
add_action( 'manage_html_block_posts_custom_column', 'populate_shortcode_column', 10, 2 );
add_filter( 'manage_edit-html_block_sortable_columns', 'add_shortcode_column' );


// Shortcode for displaying HTML Blocks
function html_block_shortcode( $atts ) {
    $atts = shortcode_atts( array(
        'id' => '',
    ), $atts );

    $html_block_id = $atts['id'];
    $html_block_content = '';

    if ( ! empty( $html_block_id ) ) {
        $html_block = get_post( $html_block_id );
        if ( $html_block && $html_block->post_type === 'html_block' ) {
            $html_block_content = apply_filters( 'the_content', $html_block->post_content );
        }
    }

    return $html_block_content;
}
add_shortcode( 'html_block', 'html_block_shortcode' );


// Register the Services post type
function services_post_type() {
	// Set UI labels for Custom Post Type
	$labels = array(
		'name'                => _x( 'Services', 'Post Type General Name', 'text-domain' ),
		'singular_name'       => _x( 'Service', 'Post Type Singular Name', 'text-domain' ),
		'menu_name'           => __( 'Services', 'text-domain' ),
		'parent_item_colon'   => __( 'Parent Service', 'text-domain' ),
		'all_items'           => __( 'All Services', 'text-domain' ),
		'view_item'           => __( 'View Service', 'text-domain' ),
		'add_new_item'        => __( 'Add New Service', 'text-domain' ),
		'add_new'             => __( 'Add New', 'text-domain' ),
		'edit_item'           => __( 'Edit Service', 'text-domain' ),
		'update_item'         => __( 'Update Service', 'text-domain' ),
		'search_items'        => __( 'Search Service', 'text-domain' ),
		'not_found'           => __( 'Not Found', 'text-domain' ),
		'not_found_in_trash'  => __( 'Not found in Trash', 'text-domain' ),
	);

	// Set other options for Custom Post Type

	$args = array(
		'label'               => __( 'Services', 'text-domain' ),
		'description'         => __( 'Service', 'text-domain' ),
		'labels'              => $labels,
		// Features this CPT supports in Post Editor
		'supports'            => array( 'title', 'editor', 'thumbnail'),
		// You can associate this CPT with a taxonomy or custom taxonomy. 
		'taxonomies'          => array( 'genres' ),
		/* A hierarchical CPT is like Pages and can have
	* Parent and child items. A non-hierarchical CPT
	* is like Posts.
	*/
		'hierarchical'        => false,
		'public'              => true,
		'show_ui'             => true,
		'show_in_menu'        => true,
		'show_in_nav_menus'   => true,
		'show_in_admin_bar'   => true,
		'menu_position'       => 5,
		'menu_icon'           => 'dashicons-list-view',
// 		'menu_icon'           => 'http://www.example.com/wp-content/uploads/2022/08/your-cpt-icon.png',
		'can_export'          => true,
		'has_archive'         => true,
		'exclude_from_search' => false,
		'publicly_queryable'  => true,
		'capability_type'     => 'post',
		'show_in_rest' => true,
	);
	// Registering your Custom Post Type
	register_post_type( 'services', $args );
}
/* Hook into the 'init' action so that the function
* Containing our post type registration is not 
* unnecessarily executed. 
*/
add_action( 'init', 'services_post_type', 0 );
//


// Register the Testimonial post type
function testimonial_post_type() {

	// Set UI labels for Custom Post Type
	$labels = array(
		'name'                => _x( 'Testimonials', 'Post Type General Name', 'text-domain' ),
		'singular_name'       => _x( 'Testimonial', 'Post Type Singular Name', 'text-domain' ),
		'menu_name'           => __( 'Testimonials', 'text-domain' ),
		'parent_item_colon'   => __( 'Parent Testimonial', 'text-domain' ),
		'all_items'           => __( 'All Testimonials', 'text-domain' ),
		'view_item'           => __( 'View Testimonial', 'text-domain' ),
		'add_new_item'        => __( 'Add New Testimonial', 'text-domain' ),
		'add_new'             => __( 'Add New', 'text-domain' ),
		'edit_item'           => __( 'Edit Testimonial', 'text-domain' ),
		'update_item'         => __( 'Update Testimonial', 'text-domain' ),
		'search_items'        => __( 'Search Testimonial', 'text-domain' ),
		'not_found'           => __( 'Not Found', 'text-domain' ),
		'not_found_in_trash'  => __( 'Not found in Trash', 'text-domain' ),
	);

	// Set other options for Custom Post Type

	$args = array(
		'label'               => __( 'testimonials', 'text-domain' ),
		'description'         => __( 'Testimonial', 'text-domain' ),
		'labels'              => $labels,
		// Features this CPT supports in Post Editor
		'supports'            => array( 'title', 'editor', 'thumbnail', 'custom-fields'),
		// You can associate this CPT with a taxonomy or custom taxonomy. 
		'taxonomies'          => array( 'genres' ),
		/* A hierarchical CPT is like Pages and can have
	* Parent and child items. A non-hierarchical CPT
	* is like Posts.
	*/
		'hierarchical'        => false,
		'public'              => true,
		'show_ui'             => true,
		'show_in_menu'        => true,
		'show_in_nav_menus'   => true,
		'show_in_admin_bar'   => true,
		'menu_position'       => 5,
		'menu_icon'           => 'dashicons-testimonial',
		'can_export'          => true,
		'has_archive'         => true,
		'exclude_from_search' => false,
		'publicly_queryable'  => true,
		'capability_type'     => 'post',
		'show_in_rest' => true,

	);

	// Registering your Custom Post Type
	register_post_type( 'testimonials', $args );

}

/* Hook into the 'init' action so that the function
* Containing our post type registration is not 
* unnecessarily executed. 
*/

add_action( 'init', 'testimonial_post_type', 0 );
// 


// Register the Gallery post type
function gallery_post_type() {
	// Set UI labels for Custom Post Type
	$labels = array(
		'name'                => _x( 'Gallery', 'Post Type General Name', 'text-domain' ),
		'singular_name'       => _x( 'Gallery', 'Post Type Singular Name', 'text-domain' ),
		'menu_name'           => __( 'Gallery', 'text-domain' ),
		'parent_item_colon'   => __( 'Parent Gallery', 'text-domain' ),
		'all_items'           => __( 'All Gallery', 'text-domain' ),
		'view_item'           => __( 'View Gallery', 'text-domain' ),
		'add_new_item'        => __( 'Add New Gallery', 'text-domain' ),
		'add_new'             => __( 'Add New', 'text-domain' ),
		'edit_item'           => __( 'Edit Gallery', 'text-domain' ),
		'update_item'         => __( 'Update Gallery', 'text-domain' ),
		'search_items'        => __( 'Search Gallery', 'text-domain' ),
		'not_found'           => __( 'Not Found', 'text-domain' ),
		'not_found_in_trash'  => __( 'Not found in Trash', 'text-domain' ),
	);

	// Set other options for Custom Post Type

	$args = array(
		'label'               => __( 'Gallery', 'text-domain' ),
		'description'         => __( 'Gallery', 'text-domain' ),
		'labels'              => $labels,
		// Features this CPT supports in Post Editor
		'supports'            => array( 'title', 'editor', 'thumbnail'),
		// You can associate this CPT with a taxonomy or custom taxonomy. 
		'taxonomies'          => array( 'gallerygenres' ),
		/* A hierarchical CPT is like Pages and can have
	* Parent and child items. A non-hierarchical CPT
	* is like Posts.
	*/
		'hierarchical'        => false,
		'public'              => true,
		'show_ui'             => true,
		'show_in_menu'        => true,
		'show_in_nav_menus'   => true,
		'show_in_admin_bar'   => true,
		'menu_position'       => 5,
		'menu_icon'           => 'dashicons-images-alt2',
		'can_export'          => true,
		'has_archive'         => true,
		'exclude_from_search' => false,
		'publicly_queryable'  => true,
		'capability_type'     => 'post',
		'show_in_rest' => true,
	);
	// Registering your Custom Post Type
	register_post_type( 'gallery', $args );
	
	register_taxonomy("gallerygenres", array("gallery"), array( "show_admin_column" => true, "hierarchical" => true, "label" => "Gallery Categories", "singular_label" => "Gallery Category", "rewrite" => array( 'slug' => 'gallery', 'with_front'=> false )));
}
/* Hook into the 'init' action so that the function
* Containing our post type registration is not 
* unnecessarily executed. 
*/
add_action( 'init', 'gallery_post_type', 0 );
//



function serv_sec() { ?>
<section class="services-sec">
	<div class="container">
		<div class="row">
			<?php if(is_front_page()):?>
			<div class="col-12">
				<div class="servSlide" id="SSlide">
					<?php
					 $service = ['post_type' => 'services','post_status' => 'publish','order' => 'ASC','posts_per_page' => -1];
					 $service_query = new WP_Query($service);
					?>
					<?php if($service_query->have_posts()): while($service_query->have_posts()): $service_query->the_post(); ?>
					<?php $thumbnail = wp_get_attachment_url( get_post_thumbnail_id(get_the_ID())); ?>
					<div class="services-item">
						<div class="services-image">
							<img src="<?php echo $thumbnail; ?>" alt="<?php the_title(); ?>">
						</div>
						<div class="services-content">
							<h3 class="title"><a href="<?php the_permalink();?>"><?php echo strip_tags(get_the_title()); ?></a></h3>
							<p class="services-txt"><?php echo strip_tags(get_the_excerpt()); ?></p>
							<div class="services-btn">
								<a class="btn-text" href="<?php the_permalink();?>">⇒</a>
							</div>
						</div>
					</div>
					<?php endwhile; endif; wp_reset_postdata(); ?>
				</div>
			</div>
			<?php else:?> 
			<?php
				$service = ['post_type' => 'services','post_status' => 'publish','order' => 'ASC','posts_per_page' => -1];
				$service_query = new WP_Query($service);
			?>
			<?php if($service_query->have_posts()): while($service_query->have_posts()): $service_query->the_post(); ?>
			<?php $thumbnail = wp_get_attachment_url( get_post_thumbnail_id(get_the_ID())); ?>
			<div class="col-12 col-md-6 col-lg-4 mb-30">
				<div class="services-item">
					<div class="services-image">
						<img src="<?php echo $thumbnail; ?>" alt="<?php the_title(); ?>">
					</div>
					<div class="services-content">
						<h3 class="title"><a href="<?php the_permalink();?>"><?php echo strip_tags(get_the_title()); ?></a></h3>
						<p class="services-txt"><?php echo strip_tags(get_the_excerpt()); ?></p>
						<div class="services-btn">
							<a class="btn-text" href="<?php the_permalink();?>">⇒</a>
						</div>
					</div>
				</div>
			</div>
			<?php endwhile; endif; wp_reset_postdata(); ?>
			<?php endif;?>
		</div>
	</div>
</section>
<?php }
add_shortcode( 'services_sec', 'serv_sec');


function testimonial_sec() { ?>
    <section class="testimonials">
        <div class="inner-testimonials-sec">
            <div class="container">
               <div class="row">
                   <div class="col-12">
                        <div class="testiBigSlide" id="TBSlide">
                        <?php
                            $testimonials = ['post_type' => 'testimonials','post_status' => 'publish','order' => 'ASC','posts_per_page' => -1];
                            $testimonials_query = new WP_Query($testimonials);
                        ?>
                        <?php if($testimonials_query->have_posts()): while($testimonials_query->have_posts()): $testimonials_query->the_post(); ?>
                        <?php $thumbnail = wp_get_attachment_url( get_post_thumbnail_id(get_the_ID())); ?>
                        <div class="item-testiBigSlide">
                            <div class="inner-item-testiBigSlide">
                                <div class="tbsCaps">
                                    <div class="in-tbsCaps">
                                        <div class="q">“</div>
                                        <p><?php echo strip_tags(get_the_content()); ?></p>
                                    </div>
                                    <div class="media-box">
                                        <div class="tImg">
                                            <img src="<?php echo $thumbnail; ?>" alt="<?php the_title(); ?>">
                                        </div>
                                        <div class="media-body">
                                            <h5 class=""><?php echo strip_tags(get_the_title()); ?></h5>
                                            <small><?php echo get_field('designation');?></small>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php endwhile; endif; wp_reset_postdata(); ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
<?php }
add_shortcode( 'testimonial_sec', 'testimonial_sec');


function gallery_sec() { ?>
  <!--YOUR CODE HERE-->
<?php }
add_shortcode( 'gallery_sec', 'gallery_sec');


// excerpt_length
function wp_example_excerpt_length( $length ) {
	return 20;
}
add_filter( 'excerpt_length', 'wp_example_excerpt_length');

// This will add a filter on `excerpt_more` that returns an empty string.
// add_filter( 'excerpt_more', '__return_empty_string' );

function new_excerpt_more( $more ) {
    return '...';
}
add_filter('excerpt_more', 'new_excerpt_more');
